==> ulyxex.1.4.3.with-tinyMce.zip: pages/admin_home.php <==
<?php
/* Ulyxex version 1.4.3 *****************/
if (!isset($admin)) exit;
if ($_SESSION['userid'] != 1) exit("you can't modify this page !");
require_once("core/admin_home.php");
/****************************************/
/* page elements						*/
$o_adminSite = New AdminSite();
$meta = $h->meta("Content-Type","text/html; charset=UTF-8");
$css = $h->css("css/".ADMINCSS,"external");
$js = $h->script("js/ulyxex.js","external");
$title = $h->title($t->wr("admin home by")."admin");
$head = $h->head($meta.$css.$js.$title);

$topPage = $h->h1($t->wr("admin home by").$h->span("admin","class='username'"));
$topPage .= $h->h2($adminNavigation->links);

$bottomPage  = $h->h3("Site Infos:");
$_ = array(
	"default css"		=> VIEWCSS,
	"articles/page"		=> ADMINITEMSBYPAGE,
	"field width"		=> FIELDWIDTH,
	"root directory"	=> getcwd(),
	"mysql-version"		=> $o_adminSite->mysql_version(),
	"host"				=> HOSTMYSQL,
	"base"				=> BASEMYSQL,
	"prefix"			=> $prefixTableMySql,
	"user"				=> USERMYSQL,
	"php-version"		=> phpversion()
);

foreach($_ as $k=>$v) {
	$bottomPage .= $h->p("- ".ucfirst($k)." : ".$h->b($v));
}
$bottomPage .= $h->p("- ".$h->ahref("admin.php?action=phpinfo","More phpinfo"));
$bottomPage .= $h->ulyxCredits($firstLine=False);
/****************************************/
/* page data							*/	
$data = "";
if (!empty($_POST['update'])) $data .= $o_adminSite->update_site_params();
$data .= $o_adminSite->site_params();

/****************************************/
/* show									*/
$bottomPage .= $h->countQ();
$body = $h->body($topPage.$data.$bottomPage);
$page = $h->html($head.$body);

echo $page;
?>

==> ulyxex.1.4.4.with-tinyMce.zip: pages/admin_home.php <==
<?php
/* Ulyxex version 1.4.4 *****************/
if (!isset($admin)) exit;
if ($_SESSION['userid'] != 1) exit("you can't modify this page !");
require_once("core/admin_home.php");
/****************************************/
/* page elements						*/
$o_adminSite = New AdminSite();
$meta = $h->meta("Content-Type","text/html; charset=UTF-8");
$css = $h->css("css/".ADMINCSS,"external");
$js = $h->script("js/ulyxex.js","external");
$title = $h->title($t->wr("admin home by")."admin");
$head = $h->head($meta.$css.$js.$title);

$topPage = $h->h1($t->wr("admin home by").$h->span("admin","class='username'"));
$topPage .= $h->h2($adminNavigation->links);

$bottomPage  = $h->h3("Site Infos:");
$_ = array(
	"default css"		=> $home['CSS'],
	"articles/page"		=> $home['ARTICLESPAGE'],
	"items/page"		=> $home['ITEMS'],
	"field width"		=> FIELDWIDTH,
	"root directory"	=> getcwd(),
	"mysql-version"		=> $o_adminSite->mysql_version(),
	"host"				=> HOSTMYSQL,
	"base"				=> BASEMYSQL,
	"prefix"			=> $prefixTableMySql,
	"user"				=> USERMYSQL,
	"php-version"		=> phpversion()
);

foreach($_ as $k=>$v) {
	$bottomPage .= $h->p("- ".ucfirst($k)." : ".$h->b($v));
}
$bottomPage .= $h->p("- ".$h->ahref("admin.php?action=phpinfo","More phpinfo"));
$bottomPage .= $h->ulyxCredits($firstLine=False);
/****************************************/
/* page data							*/	
$data = "";
if (!empty($_POST['update'])) $data .= $o_adminSite->update_site_params();
$data .= $o_adminSite->site_params();

/****************************************/
/* show									*/
$bottomPage .= $h->countQ();
$body = $h->body($topPage.$data.$bottomPage);
$page = $h->html($head.$body);

echo $page;
?>
